@@ -139,7 +139,7 @@ QColor ColorProxyModel::getCollectionColor(Akonadi::Collection collection) const
     }
     
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup resourcesColorsConfig(config, "Resources Colors");
+    KConfigGroup resourcesColorsConfig(config, QStringLiteral("Resources Colors"));
     const QStringList colorKeyList = resourcesColorsConfig.keyList();
     
     QColor color;
